##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 9: Hypothesis Tests                                            #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################



##########################################################################
# 9.3 Population Mean: sigma Known                                       #
##########################################################################
# ҥCDѪ(Coffee.xlsx)Pҥ@ˡA
# GUCGҥ@ˡA{XλykOT

library(readxl)
Coffee <- read_excel("data/chap09/Coffee.xlsx")
# Coffee <- read.csv("data/chap09/Coffee.csv")

str(Coffee)
Coffee$Weight
n <- length(Coffee$Weight)
n

# z-test
# One-Tailed Test
# install.packages("BSDA") # Basic Statistics and Data Analysis
library(BSDA)

# Lower Tail Test: H0: mu >= 3
z.test(Coffee$Weight, alternative = "less", mu = 3, sigma.x = 0.18,
       conf.level = 0.95)

# Upper Tail Test: H0: mu <= 3
z.test(Coffee$Weight, alternative = "greater", mu = 3, sigma.x = 0.18,
       conf.level = 0.95)

# Two-Tailed Test: H0: mu == 3
z.test(Coffee$Weight, alternative = "two.sided", mu = 3, sigma.x = 0.18,
       conf.level = 0.95)

# get p-value from the output of the Two-Tailed Test
output <- z.test(Coffee$Weight, alternative = "two.sided", mu = 3, sigma.x = 0.18,
       conf.level = 0.95)

output
str(output)
output$p.value
output$statistic # z value



##########################################################################
# 9.4 Population Mean: sigma Unknown                                     #
##########################################################################


AirRating <- read_excel("data/chap09/AirRating.xlsx")
# AirRating <- read.csv("data/chap09/AirRating.csv")
str(AirRating)
AirRating$Rating

# One sample t-test
# Lower Tail Test: H0: mu >= 7
t.test(AirRating$Rating, alternative = "less", mu = 7,
       conf.level = 0.95)

# Upper Tail Test: H0: mu <= 7
t.test(AirRating$Rating, alternative = "greater", mu = 7, 
       conf.level = 0.95)

# Two-Tailed Test: H0: mu == 7
t.test(AirRating$Rating, alternative = "two.sided", mu = 7,
       conf.level = 0.95)


# get 95% CI from the output of the Two-Tailed t-Test
output2 <- t.test(AirRating$Rating, alternative = "two.sided", mu = 7,
       conf.level = 0.95)

str(output2)
output2$conf.int 


##########################################################################
# 9.5 Population Proportion                                              #
##########################################################################

# Pine Creek golf course example: H0: p <= 0.20, Ha: p > 0.20
# determine whether the proportion of women golfers increased
n <- 400
x <- 100
p.bar <- x/n   
p.bar
(n * p.bar >= 5) & (n * (1 - p.bar) >= 5)

# z test statistic
p0 <- 0.20
z0 <- (p.bar - p0)/sqrt(p0 * (1 - p0)/n)
z0

alpha <- 0.05

p.value <- 1 - pnorm(z0)  # P(z > z0)
p.value < alpha # if TRUE, then H0 is rejected

qnorm(alpha)  # lower tail
qnorm(1 - alpha)  # upper tail
z0 > qnorm(1 - alpha) # if TRUE, then H0 is rejected



##########################################################################
# 9.7 Calculating the Probability of Type II Errors                      #
##########################################################################

# lot-acceptance example described in Section 9.6.
# mu:  the mean number of hours of useful life for batteries in the shipment
# H0: mu >= mu0, Ha: mu < mu0 
mu0 <- 120
sigma <- 12
n <- 36
alpha <- 0.05
z.alpha <- qnorm(1 - alpha)
xbar <- mu0 - z.alpha * (sigma/sqrt(n))
xbar

# Compute probability of the Type II error when mu = 112
mu <- 112
z <- (xbar - mu)/(sigma/sqrt(n))
z
P.typeII.error <- 1 - pnorm(z)
P.typeII.error
power <- 1 - P.typeII.error
power


##########################################################################
# 9.8 Determining n for a Hypothesis Test about a Population Mean        #
##########################################################################

# n = ((za + zb)^2 * sigma^2) / (mu0 - mua)^2
 
alpha <- 0.05
beta <- 0.1
za <- qnorm(1-0.05)
zb <- qnorm(1-0.1)
mu0 <- 120
mua <- 115
sigma <- 12

n <- ceiling(((za + zb)^2 * sigma^2) / (mu0 - mua)^2)
n



