##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 11: Inferences About Population Variances                      #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################

##########################################################################
# 11.1 Inferences about a population variance                            #
##########################################################################

# Interval Estimation
# p530
# interval estimate for the population variance of filling quantities.

n <- 20 # the sample of 20 containers
s2 <- 0.0025
alpha <- 0.05
qchisq(alpha/2, 19)
qchisq(1 - alpha/2, 19)

# 95% CI for sigma2
ci <- c((n - 1) * s2/qchisq(1 - alpha/2, 19), (n - 1) * s2/qchisq(alpha/2, 19))
round(ci, 4)
round(sqrt(ci), 4)




# Hypothesis Testing
# p.531
# determine whether the arrival time population variance is excessive.
# H0: sigma2 leq 4

BusTimes <- read_excel("data/chap11/BusTimes.xlsx")
BusTimes
print(BusTimes, n = 24)

library(EnvStats)
#varTest(x, alternative = "two.sided", conf.level = 0.95, 
#        sigma.squared = 1, data.name = NULL)

varTest.result <- varTest(BusTimes$Times, alternative = "greater", conf.level = 0.95, 
                          sigma.squared = 4)
varTest.result



# FIGURE 11.3
x <- seq(0, 50, 0.1)
plot(x, dchisq(x, 23), type = "l", main = "Chi-Square Distribution with df = 23")
arrows(varTest.result$statistic, dchisq(varTest.result$statistic, 23),
       varTest.result$statistic, 0)
text(varTest.result$statistic, 0, labels = paste("chi-square stat = ", 
                                                 round(varTest.result$statistic, 2)))

text(35, 0.005, labels = paste("p-value = ", round(varTest.result$p.value, 4)))



# p.533
# two-tailed test about a population variance by considering
# a situation faced by a bureau of motor vehicles
# the variance in test scores
# for individuals applying for drivers licenses has been sigma2 = 100
# H0: sigma2 = 100

alpha <- 0.05
n <- 30
s2 <- 162
sigma2 <- 100

chisq.stat <- ((n - 1) * s2) / sigma2
chisq.stat
p.value <- 2 * (1 - pchisq(chisq.stat, n - 1))  
p.value
  


##########################################################################
# 11.2 Inferences about two population variances                         #
##########################################################################



# FIGURE 11.4
# F(20, 20)
x <- seq(0, 4, 0.1)
plot(x, df(x, 20, 20), type = "l", main = "F distribution with df1 = 20, df2 = 20")


# p.539
# Dullus County Schools is renewing its school bus service contract for the coming year
# and must select one of two bus companies, the Milbank Company or the Gulf Park Company.
# We will use the variance of the arrival or pickup/delivery times as a primary measure
# of the quality of the bus service.
# H0:  sigma2.1 = sigma2.2


SchoolBus <- read_excel("data/chap11/SchoolBus.xlsx")
SchoolBus
SchoolBus_Milbank <- SchoolBus$Milbank[1:26]
SchoolBus_GulfPark <- SchoolBus$`Gulf Park`[1:16]
var(SchoolBus_Milbank)
var(SchoolBus_GulfPark)

var.test(SchoolBus_Milbank, SchoolBus_GulfPark, conf.level = 0.9)
# p-value = 0.0811, reject H0 at alpha = 0.1



# One-tailed tests
# H0:  sigma2.1 leq sigma2.2
# p.541
# test to see whether the sample data indicate that women show a 
# greater variation in attitude on political issues than men

n1 <- 41 # women 
n2 <- 31 # men
sigma2.1 <- 120
sigma2.2 <- 80
F.stat <- sigma2.1 / sigma2.2
p.value <- 1 - pf(F.stat, n1 - 1, n2 - 1)
p.value

