##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# # Chapter 12: Comparing Multiple Proportions, Test of Independence     #
#               and Goodness of Fit                                      #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################


##########################################################################
# 12.1 Testing the Equality of Population Proportions for Three or       #
#      More Populations                                                  #
##########################################################################

# p.555
# p1 (p2, p3) = proportion likely to repurchase an Impala (Fusion, Accord) for the population of 
# Chevrolet Impala (Ford Fusion, Honda Accord) owners


AutoLoyalty <- read_excel("data/chap12/AutoLoyalty.xlsx")
AutoLoyalty

# TABLE 12.1
AutoLoyalty.table <- t(table(AutoLoyalty))
AutoLoyalty.table
margin.table(AutoLoyalty.table, 1)
margin.table(AutoLoyalty.table, 2)


chisq.test(AutoLoyalty.table)


# critical value for the chi-square test statistic
# chi-sqaure = 5.991
qchisq(1 - 0.05, 2)  # textbook: upper, R: lower



# A Multiple Comparison Procedure
n <- margin.table(AutoLoyalty.table, 2)
n
p_bar <- AutoLoyalty.table[2,] / n
p_bar

# critical value eq (12.3)
CV <- function(p_bar_i, p_bar_j, ni, nj, alpha, k){
  
  sqrt(qchisq(1 - alpha, k - 1)) * sqrt((p_bar_i * (1 - p_bar_i)) / ni +
                                        (p_bar_j * (1 - p_bar_j)) / nj)
}

CV(p_bar[1], p_bar[2], n[1], n[2], 0.05, 3)
CV(p_bar[1], p_bar[3], n[1], n[3], 0.05, 3)
CV(p_bar[2], p_bar[3], n[2], n[3], 0.05, 3)

PairwiseComparison <- dimnames(AutoLoyalty.table)$Automobile
PairwiseComparison


# TABLE 12.5 Pairwise Comparison Tests for the Automobile Brand Loyalty Study
cat("Pairwise Comparison: \n")
for(i in 1:3){
  j <- 3
  while(i < j){
    cat(PairwiseComparison[i], " vs ", PairwiseComparison[j], "\n")    
    value1 <- abs(p_bar[i] - p_bar[j])
    cat("| p_bar_i - p_bar_j | = ", value1, ", \t")
    value2 <- CV(p_bar[i], p_bar[j], n[i], n[j], 0.05, 3)
    cat(" CV_ij = ", value2, "\t")
    # Significant
    cat(ifelse(value1 > value2, "*Significant \n", "\n"))
    j <- j - 1
  }
}






##########################################################################
# 12.2 Test of independence                                              #
##########################################################################


# p.565
# H0: Beer preference is independent of gender

BeerPreference <- read_excel("data/chap12/BeerPreference.xlsx")
BeerPreference

# TABLE 12.6
table(BeerPreference[c("Preference", "Gender")])
prop.table(table(BeerPreference[c("Preference", "Gender")]), 1)
prop.table(table(BeerPreference[c("Preference", "Gender")]), 2)

chisq.test(BeerPreference$Preference, BeerPreference$Gender)

chisq.test(table(BeerPreference[c("Preference", "Gender")]))


# FIGURE 12.1
library(ggplot2)
pt <- as.data.frame(prop.table(table(BeerPreference[c("Preference", "Gender")]), 2))
ggplot(pt, aes(x = Preference, y = Freq, fill = Gender)) +
  geom_bar(stat="identity", position="dodge") +
  labs(title = "Bar Chart Comparison of Beer Preference by Gender")




##########################################################################
# 12.3 Goodness of fit test                                              #
##########################################################################

# Multinomial Probability Distribution
# p.573
# pA (pB, pC) = probability a customer purchases the company A (B, C) product
# H0: pA = .30, pB = .50, and pC = .20

# Observed Frequency
observed_freq <- c(48, 98, 54)
expected_prop <- c(0.3, 0.5, 0.2)
sum(expected_prop)
chisq.test(x = observed_freq, p = expected_prop)





# Normal Probability Distribution

# p.577
# goodness of fit test for a normal distribution by considering
# the job applicant test data for Chemline, Inc.,

Chemline <- read_excel("data/chap12/Chemline.xlsx")
Chemline
Chemline$Score

Percentage <- seq(0.1, 0.9, 0.1)
z <- round(qnorm(Percentage), 2)
xbar <- mean(Chemline$Score)
s <- round(sd(Chemline$Score), 2)
TestScore <- round(xbar + z * s, 2)
TestScore

Test_Score_Interval <- cut(Chemline$Score, breaks = c(min(Chemline$Score) - 1, 
                               TestScore, max(Chemline$Score) + 1))
Test_Score_Interval

Observed_Frequency <- c(table(Test_Score_Interval))
Observed_Frequency
Expected_Frequency <- rep(50/10, 10) # n =50, 10 = #interval


chisq.test(x = Observed_Frequency, p = Expected_Frequency/50)
# X-squared = 7.2, df = 9, p-value = 0.6163
# textbook : df = 7 (k-p-1=10-2-1, p = mean and sd are estimated)

chi2 <- sum((Observed_Frequency - Expected_Frequency)^2 / Expected_Frequency)
chi2
p.value <- pchisq(chi2, df = 7, lower.tail = F)
p.value


