##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 18: Nonparametric Methods                                      #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################


##########################################################################
# 18.1 Sign Test                                                         #
##########################################################################


# TABLE 18.1 
# One-Week Sales of Cape May Potato Chips at 10 Lawler Grocery Stores


Sales <- data.frame(StroeNUmer = c(56, 19, 36, 128, 12, 63, 39, 84, 102, 44),
                    WeeklySales = c(485, 562, 415, 860, 426, 474, 662, 380, 515, 721))

Sales

# TABLE 18.3 
# Binomial Probabilities with n = 10 and p =  0.50
PP <- data.frame(PlusSigns = 0:10, 
           Probability = round(dbinom(0:10, size = 10, prob = 0.5), 4))
PP


# Figure 18.1 
# Binomial Sampling Distribution for the Number of Plus Signs When n = 10 and p = .50

plot(PP, type = "h", 
     xlab = "Number of Plus Signs", 
     ylab = "Probability", 
     main = "Binomial Sampling Distribution for the Number of Plus Signs")


library(BSDA)
SIGN.test(Sales$WeeklySales, md = 450, alternative = "greater")



# Normal approximation of the sampling distribution of the number
# of plus signs when H0: p = 0.50
library(readxl)
HomeSales <- read_excel("data/Chap18/HomeSales.xlsx")
print(HomeSales)
SIGN.test(HomeSales$"Sales Price $", md = 236000, alternative = "less")


hypothesized.value <- 236000
SalesPrice <- HomeSales$"Sales Price $"[HomeSales$"Sales Price $" !=  hypothesized.value]
PlusSign <- length(SalesPrice[SalesPrice > hypothesized.value])
PlusSign
# PlusSign = 22
n <- length(SalesPrice)
mu <- 0.5 * n
sigma <- sqrt(0.25*n)
# p.value = P(x < =  22.5) # continuous correction
p.value <- pnorm(((PlusSign + 0.5) - mu)/sigma)
p.value



# Hypothesis Test with Matched Samples
# TABLE 18.4 
# Preference Data for the Sun Coast Farms Taste Test

Preference <- c("Tropical Orange", "Tropical Orange", "Citrus Valley", 
                "Tropical Orange", "Tropical Orange", "No Preference", 
                "Tropical Orange", "Tropical Orange", "Tropical Orange", 
                "No Preference", "Tropical Orange", "Citrus Valley", 
                "Tropical Orange", "Tropical Orange") 

Preference.used <- Preference[Preference !=  "No Preference"]
no <- length(Preference.used)
# wrong: SIGN.test(Preference.plus, md = 0.5 * no, alternative = "two.sided")
Plus.no <- length(which(Preference.used  ==  "Citrus Valley"))
p.value <- sum(dbinom(0:Plus.no, size = no, prob = 0.5))*2
p.value





##########################################################################
# 18.2 Wilcoxon Signed-Rank Test                                         #
##########################################################################

# TABLE 18.6 
# Production Task Completion Times (Minutes)
Production <- matrix(c(
  1, 10.2, 9.5,
  2, 9.6, 9.8, 
  3, 9.2, 8.8, 
  4, 10.6, 10.1,
  5, 9.9, 10.3, 
  6, 10.2, 9.3, 
  7, 10.6, 10.5,
  8, 10.0, 10.0,
  9, 11.2, 10.6,
  10, 10.7, 10.2,
  11, 10.6, 9.8), ncol = 3, byrow = T)

Production <- as.data.frame(Production)
colnames(Production) <- c("Worker", "Method.A", "Method.B")
Production
wilcox.test(Production$Method.A, Production$Method.B, paired = TRUE, exact = F, correct = T) 
wilcox.test(Production$Method.A, Production$Method.B, paired = TRUE, exact = F, correct = F) 
# Book page 943: p-value = 0.0286, T+ = 49.5




##########################################################################
# 18.3 Mann-Whitney-Wilcoxon Test                                        #
##########################################################################

# TABLE 18.8 
# Performance Ratings for a Sample of College Students and a
# Sample of High School Students Working at Showtime Cinemas
Performance <- data.frame(Student = c(rep("C", 4), rep("H", 5)),
                      Rating = c(15, 3, 23, 8, 18, 20, 32, 9, 25))

# TABLE 18.10 
# Probabilities for the Exact Sampling Distribution of the Sum of
# the Ranks for the Sample of College Students

no.student <- nrow(Performance)
first <- sum(1:4) # sum of ranks for the first 4 places 
last <- sum(6:9) # sum of ranks for the last 4 places 

# CCCCHHHHH: sum of ranks = 10
factorial(4)*factorial(5)/factorial(9)
# CCCHCHHHH: sum of ranks = 11
factorial(3)*choose(5, 1)*choose(4, 1)*factorial(4)/factorial(9)
# CCCHHCHHH: sum of ranks = 12
# CCHCCHHHH: sum of ranks = 12
factorial(3)*factorial(2)*choose(4, 1)*factorial(3)*choose(5, 3)/factorial(9) + 
  factorial(2)*choose(5, 1)*choose(4, 2)*factorial(2)*factorial(4)/factorial(9)

# Mann-Whitney-Wilcoxon Test
wilcox.test(Performance$Rating ~ Performance$Student) 



# TABLE 18.11 
# Account Balances for Two Branches of Third National Bank

AccountBalances <- data.frame(Account = c(rep("B1", 12), rep("B2", 10)),
                              Balance  = c(1095, 955, 1200, 1195, 925, 950, 805, 945,
                                         875, 1055, 1025, 975, 885, 850, 915, 950,
                                         800, 750, 865, 1000, 1050, 935))
  

wilcox.test(AccountBalances$Balance ~ AccountBalances$Account, exact = F) 
# page. 953: p-value = 0.0414 




##########################################################################
# 18.5 Rank Correlation                                                  #
##########################################################################

PotentialActual <- read_excel("data/Chap18/PotentialActual.xlsx")
print(PotentialActual)
cor(PotentialActual[,2:3], method = "pearson")
cor(PotentialActual[,2:3], method = "spearman")

cor.test(PotentialActual$Potential, PotentialActual$`Two-Year Sales`, 
         method = "spearman", exact = T, continuity = T)

cor.test(PotentialActual$Potential, PotentialActual$`Two-Year Sales`, 
         method = "spearman", exact = F, continuity = T)

# page. 963, p-value = 0.0278



